{ nix-flatpak, lib, pkgs, inputs, ... }:
{

  nixpkgs.config.allowUnfree = true;

  home = {
    packages = with pkgs; [
      just
      yt-dlp
      erdtree
      age
      figlet
      ffmpeg-full
      rlwrap
      pinentry
      gcr
      gnutar
      unzip
      zip
      htop
      #owl
      #opendrop
      dconf
      gnupg
      gcc
      gnutls
      gettext
      xorg.libX11
      freetype.dev
      gnumake
      flex
      bison
      mesa
      neofetch
      nitch
      ripgrep-all
      silver-searcher
      xclip
      maestral
      maestral-gui
      sane-airscan
      xsane
      dbus
      gst_all_1.gstreamer
      alsa-oss
      fontconfig
      powertop
      usbutils
      pciutils
      util-linux
      coreutils
      binutils
      libgcc
      raylib
      SDL2.dev
      protonplus
      ispell
      aspell
      aspellDicts.en
      aspellDicts.en-computers
      texlive.combined.scheme-full
      appimage-run
      #transmission_4
      transmission_4-gtk
      lsof
      ruby
      janet
      jpm
      python3
      ruff
      python311Packages.pip
      sbcl
      nodejs_18
      platformio-core
      kanata-with-cmd
      icloudpd
      libheif
      libheif.out
      openal

      # node packages
      nodePackages.typescript-language-server
      nodePackages.vscode-langservers-extracted

      nodePackages.prettier
      nodePackages.javascript-typescript-langserver

      nodePackages.stylelint
      nodePackages.svelte-language-server
      nodePackages.typescript

      nixd

      fishPlugins.foreign-env
      fishPlugins.z
      fishPlugins.fzf
      fishPlugins.bass
      fishPlugins.autopair

      via
      bitwarden-cli
      bitwarden-desktop
      rbw
      tailscale
      font-manager
      gnomeExtensions.just-perfection
      gnomeExtensions.dash-to-dock
      gnomeExtensions.solaar-extension
      gnomeExtensions.kmonad-toggle
      gnome-software
      gnome-tweaks
      gnome-photos
      sushi
      colloid-gtk-theme
      colloid-icon-theme
      whitesur-gtk-theme
      whitesur-cursors
      whitesur-icon-theme
      graphite-gtk-theme
      graphite-cursors
      waycorner

      icloudpd
      squirreldisk
      papers
      newsflash
      planify
      fuzzel

      wineWowPackages.stagingFull
      wineWowPackages.fonts
      winetricks

      spice
      spice-gtk
      spice-protocol
      virt-viewer
      virt-manager
      solaar
      logitech-udev-rules

      #syncthingtray
      impression
      zoom-us
      nyxt
      ungoogled-chromium
      obsidian
      vlc
      polychromatic
      discord
      slack
      signal-desktop
      libreoffice
      plexamp
      carla
      wireplumber
      audacity
      supercollider-with-plugins
      bitwig-studio
      blender
      davinci-resolve-studio
      steam
      zotero_7
      handbrake
      renoise
      yabridge
      yabridgectl
      ansel
      rawtherapee
      inkscape
      gimp
      epson-escpr
      kicad
      openscad-unstable
      openscad-lsp
      picard
      evolutionWithPlugins
      mpv
      plugdata
      pavucontrol
      qpwgraph
      alsa-utils
      alsa-tools
      clapper
      amberol
      ardour
      parinfer-rust-emacs
      ardour
      # Audio plugins (LV2, VST2, VST3, LADSPA)
      distrho
      eq10q
      lsp-plugins
      geonkick
      bespokesynth
      helm
      surge
      odin2
      tunefish
      calf

      # Fonts
      fira-code
      fira
      cooper-hewitt
      ibm-plex
      jetbrains-mono
      iosevka
      # bitmap
      spleen
      fira-code-symbols
      powerline-fonts
      nerdfonts
    ];

    username = "emenel";
    homeDirectory = "/home/emenel";

    sessionPath = [ "/home/emenel/.config/emacs/bin" "/home/emenel/.npm-packages/bin" "/home/emenel/Applications" "/home/emenel/.local/bin" "/home/emenel/.local/share" ];

    sessionVariables = {
      EDITOR = "emacsclient -r";
      WINEFSYNC = 1;
    };

    stateVersion = "24.05";
  };

  fonts.fontconfig.enable = true;

  programs = {
    home-manager.enable = true;

    direnv = {
      enable = true;
      nix-direnv.enable = true;
    };
    fish = {
      enable = true;
      shellAliases = {
        "ls" = "eza";
        ".j" = "just -g";
      };
    };
    starship = {
      enable = true;
      enableFishIntegration = true;
    };
    mu.enable = true;
    mbsync.enable = true;
    msmtp.enable = true;
    emacs = {
      enable = true;
      package = pkgs.emacs;
      extraPackages = epkgs: [
        epkgs.mu4e
        epkgs.vterm
      ];
    };
    ripgrep = {
      enable = true;
    };
    thefuck = {
      enable = true;
      enableFishIntegration = true;
    };
    wezterm = {
      enable = true;
    };
    bat = {
      enable = true;
    };
    # borgmatic = {
    #   enable = true;
    # };
    eza = {
      enable = true;
      enableFishIntegration = true;
    };
    fd = {
      enable = true;
    };
    fzf = {
      enable = true;
      enableFishIntegration = true;
    };
    git = {
      enable = true;
      lfs.enable = true;
    };
    htop.enable = true;
    nnn = {
      enable = true;
    };
    pandoc.enable = true;
    password-store.enable = true;
    #waybar.enable = true;
    lazygit.enable = true;
    jq.enable = true;
    firefox.enable = true;
  };

  home.sessionVariables.NIXOS_OZONE_WL = "1";

  dconf.settings = {
    "org/gnome/desktop/background" = {
      picture-options = "none";
      primary-color = "#222222";
    };

    "org/gnome/shell/keybindings" = {
      shift-overview-up = ["disabled"];
      shift-overview-down = ["disabled"];
      switch-to-application-1 = ["disabled"];
      switch-to-application-2 = ["disabled"];
      switch-to-application-3 = ["disabled"];
      switch-to-application-4 = ["disabled"];
      switch-to-application-5 = ["disabled"];
      switch-to-application-6 = ["disabled"];
      switch-to-application-7 = ["disabled"];
      switch-to-application-8 = ["disabled"];
      switch-to-application-9 = ["disabled"];
      switch-to-application-10 = ["disabled"];
    };
  };

  nixpkgs.config.packageOverrides = pkgs: {
    renoise = pkgs.renoise.override {
      releasePath = /home/emenel/temp/rns_344_linux_x86_64.tar.gz;
    };
  };

  services = {
    flatpak.enable = true;
    syncthing = {
      enable = true;
      #tray.enable = true;
    };
  };

  # wayland.windowManager.sway = {
  #   enable = true;
  #   config = rec {
  #     modifier = "Mod4";
  #     terminal = "wezterm";
  #     startup = [
  #       # Launch Firefox on start
  #       {command = "firefox";}
  #     ];
  #   };
  # };

  # kanshi systemd service
  # systemd.user.services.kanshi = {
  #   #description = "kanshi daemon";
  #   environment = {
  #     WAYLAND_DISPLAY="wayland-1";
  #     DISPLAY = ":0";
  #   };
  #   serviceConfig = {
  #     Type = "simple";
  #     ExecStart = ''${pkgs.kanshi}/bin/kanshi -c kanshi_config_file'';
  #   };
  # };

  xdg.systemDirs.data = [
    "/home/emenel/.local/share/applications/wine/Programs"
    "/home/emenel/.local/share/applications"
    "/var/lib/flatpak/exports/share"
    "/home/emenel/.local/share/flatpak/exports/share"
    "/home/emenel/.nix-profile/share/applications"
  ];

  services.flatpak.packages = [
    "io.github.zen_browser.zen"
    "com.github.johnfactotum.QuickLookup"
    "com.heroicgameslauncher.hgl"
    "io.github.dyegoaurelio.simple-wireplumber-gui"
    "io.github.dgsasha.Remembrance"
    "nl.hjdskes.gcolor3"
  ];

  home.file.".npmrc".source = ../dotfiles/dot_npmrc;
  xdg.configFile."kmonad".source = ../dotfiles/dot_config/kmonad;
  xdg.configFile."just/justfile".source = ../dotfiles/dot_config/just/justfile;
  xdg.configFile."starship.toml".source = ../dotfiles/dot_config/starship.toml;
  xdg.configFile."wezterm".source = ../dotfiles/dot_config/wezterm;
  xdg.configFile."git".source = ../dotfiles/dot_config/git;
  home.file.".sbclrc".source = ../dotfiles/dot_sbclrc;
  home.file.".signature".source = ../dotfiles/dot_signature;
  home.file.".config/fish/functions" = {
    source = ../dotfiles/dot_config/fish/functions;
    recursive = true;
  };

  xdg.configFile."emacs".enable = false;
  home.file.".msmtprc".source = ../dotfiles/dot_msmtprc;
  home.file.".mbsyncrc".source = ../dotfiles/dot_mbsyncrc;

  home.file.".local/share/flf".source = ../dotfiles/dot_local/share/flf;
}
